<?php
/**
 * Plugin Name: Fourbis Woocommerce Email Report
 * Plugin URI:
 * Author: 4BIS Innovations B.V
 * Author URI: https://4bis.nl
 * Description: Fourbis plugin for a monthly overview of your WooCommerce sales
 * Version: 1.01
 */

if (!defined('ABSPATH')) exit;

define('WOO_REPORT_PATH', plugin_dir_path(__FILE__));
define('WOO_REPORT_WEB_PATH', plugin_dir_url(__FILE__));

/**
 * Check if WooCommerce is active
 **/
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

    include(WOO_REPORT_PATH . '/fourbis_email_rapport_functions.php');

    function fwer_settings_page()
    {
        add_menu_page('4BIS WC Email report', 'WC Email Rapport', 'manage_options', 'wc-email-report', 'fwer_monthly_mail_page', 'dashicons-4bis');

        add_action('admin_init', 'fwer_wc_settings_init');
    }
    add_action('admin_menu', 'fwer_settings_page');
}
else{
    add_action('admin_notices', 'fwer_error_install_wc');
}

/**
 * Error message if wc is not installed
 **/

function fwer_error_install_wc(){
    ?>
    <div class="error notice">
        <p><?php _e( 'Please install and activate WooCommerce for Fourbis WooCommerce Email Report to work!', 'wc-email-report' ); ?></p>
    </div>
    <?php
}

/**
 * Settings for the report
 **/

function fwer_wc_settings_init()
{
    //schedule daily cron
    if (!wp_next_scheduled('fwer_email_cron_monthly')) {
        wp_schedule_event(time(), 'daily', 'fwer_email_cron_monthly');
    }

    wp_register_style('fourbis-email-report-style', plugins_url('css/fourbis-email-rapport-style.css', __FILE__));
    wp_enqueue_style('fourbis-email-report-style');

    //Monthly mail settings
    add_settings_section(
        'settings_section',
        '',
        '',
        'wc-monthly-settings'
    );
    register_setting(
        'fwer_settings',
        'fwer_main_mail_settings'
    );
    add_settings_field(
        'mail_to',
        'Mail to:',
        'fwer_mail_to',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'mail_cc',
        'Mail CC:',
        'fwer_mail_cc',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'mail_subject',
        'Mail subject:',
        'fwer_mail_subject',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'mail_from',
        'Mail from:',
        'fwer_mail_from',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'table_color',
        'Table color:',
        'fwer_table_color',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'table_head_text_color',
        'Table header text color:',
        'fwer_tablehead_text_color',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'table_cell_text_color',
        'Table cell text color:',
        'fwer_tablecell_text_color',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'prijspstukexclbtw',
        'Show product price excl. VAT:',
        'fwer_prijs_pp_exclbtw',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'btw_price_apiece',
        'Show VAT per product:',
        'fwer_btw_price_apiece',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'hoeveelheid',
        'Show quantity:',
        'fwer_hoeveelheid',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'btw',
        'Show VAT total:',
        'fwer_btw',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'prijs_totaal_excl_btw',
        'Show total price excl. VAT:',
        'fwer_prijs_totaal_exclbtw',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'billing_email',
        'Show the customers email:',
        'fwer_billing_email',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'billing_country',
        'Show the customers country:',
        'fwer_billing_country',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'billing_phone',
        'Show the customers phone number:',
        'fwer_billing_phone',
        'wc-monthly-settings',
        'settings_section'
    );
    add_settings_field(
        'mail_comment',
        'Comments: ',
        'fwer_mail_comment',
        'wc-monthly-settings',
        'settings_section'
    );
}

/**
 * Callbacks for individual settings
 **/

function fwer_mail_to()
{
    $mailto = esc_attr(get_option('fwer_main_mail_settings')['to']);
    ?>
    <div style="margin: 0">
        <input class="customInput" id="mail_to" type="text" name="fwer_main_mail_settings[to]"
               value="<?php echo $mailto; ?>"
        >
    </div>
    <p id="descP"><i>Add multiple recipients by separating them with a comma. example@example.com, example@example.nl</i>
    </p>
    <?php
}

function fwer_mail_cc()
{
    $cc = esc_attr(get_option('fwer_main_mail_settings')['cc']);
    ?>
    <div>
        <input class="customInput" id="mail_cc" type="text" name="fwer_main_mail_settings[cc]" value="<?php echo $cc; ?>"
        >
    </div>
    <p id="descP"><i>Add multiple CC's
            by separating them with a comma. example@example.com, example@example.nl</i>
    </p>
    <?php
}

function fwer_mail_subject()
{
    $subject = esc_attr(get_option('fwer_main_mail_settings')['subject']);
    ?>
    <div>
        <input class="customInput" id="mail_subject" type="text" name="fwer_main_mail_settings[subject]"
               value="<?php echo $subject; ?>"
        >
    </div>
    <p id="descP"><i>Mail subject.</i></p>
    <?php
}

function fwer_mail_from()
{
    $mailfrom = esc_attr(get_option('fwer_main_mail_settings')['from']);
    ?>
    <div>
        <input class="customInput" id="mail_from" type="email" name="fwer_main_mail_settings[from]"
               value="<?php echo $mailfrom; ?>"
        >
    </div>
    <p id="descP"><i>The sender of the email.</i></p>
    <?php
}

function fwer_table_color()
{
    $tablecolor = esc_attr(get_option('fwer_main_mail_settings')['table_color']);
    ?>
    <div>
        <input class="customInputColor" id="table_color" type="color" name="fwer_main_mail_settings[table_color]"
               value="<?php echo $tablecolor; ?>"
        >
        <?php echo " " . $tablecolor ?>
    </div>
    <?php
}

function fwer_tablehead_text_color()
{
    $tableheadtextcolor = esc_attr(get_option('fwer_main_mail_settings')['table_head_text_color']);
    ?>
    <div>
        <input class="customInputColor" id="table_head_text_color" type="color"
               name="fwer_main_mail_settings[table_head_text_color]"
               value="<?php echo $tableheadtextcolor; ?>"
        >
        <?php echo " " . $tableheadtextcolor ?>
    </div>
    <?php
}

function fwer_tablecell_text_color()
{
    $tablecelltextcolor = esc_attr(get_option('fwer_main_mail_settings')['table_cell_text_color']);
    ?>
    <div>
        <input class="customInputColor" id="table_cell_text_color" type="color"
               name="fwer_main_mail_settings[table_cell_text_color]"
               value="<?php echo $tablecelltextcolor; ?>"
        >
        <?php echo " " . $tablecelltextcolor ?>
    </div>
    <?php
}

function fwer_billing_email()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[billing_email]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['billing_email']), 1); ?>
        >
    </div>
    <?php
}

function fwer_billing_country()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[billing_country]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['billing_country']), 1); ?>
        >
    </div>
    <?php
}

function fwer_billing_phone()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[billing_phone]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['billing_phone']), 1); ?>
        >
    </div>
    <?php
}

function fwer_btw()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[btw]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['btw']), 1); ?>
        >
    </div>
    <?php
}

function fwer_btw_price_apiece()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[btw_price_apiece]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['btw_price_apiece']), 1); ?>
        >
    </div>
    <?php
}

function fwer_prijs_pp_exclbtw()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[prijspstukexclbtw]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['prijspstukexclbtw']), 1); ?>
        >
    </div>
    <?php
}

function fwer_hoeveelheid()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[hoeveelheid]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['hoeveelheid']), 1); ?>
        >
    </div>
    <?php
}

function fwer_prijs_totaal_exclbtw()
{
    ?>
    <div>
        <input type="checkbox" name="fwer_main_mail_settings[prijs_totaal_excl_btw]"
               value="1" <?php checked(esc_attr(get_option('fwer_main_mail_settings')['prijs_totaal_excl_btw']), 1); ?>
        >
    </div>
    <?php
}

function fwer_mail_comment()
{
    $mail_comment = esc_attr(get_option('fwer_main_mail_settings')['mail_comment'])
    ?>
    <div>
        <input class="customInput" type="text" name="fwer_main_mail_settings[mail_comment]"
               value="<?php echo $mail_comment ?>"
        >
    </div>
    <?php
}

/**
 * Settings page
 **/

function fwer_monthly_mail_page()
{
    ?>
    <div class="bg-page"></div>
    <div class="row title_row">
        <div class="description_email_report">
            <h1>Mail settings for the monthly email report</h1>
            <p>On this page you can adjust settings for the monthly automatic email report.</p>
        </div>
        <div class="fourbis_logo_wrapper">
            <img class="fourbislogo" src="<?php echo WOO_REPORT_WEB_PATH . "4BI_2019_EMAIL_logo.png";?>"/>
        </div>
    </div>
    <?php
    if (!current_user_can('manage_options')) {
        return;
    } ?>
    <div id="settings" class="wrap wrapCustom">
        <?php settings_errors(); ?>
        <form method="POST" action="options.php">
            <?php settings_fields('fwer_settings'); ?>
            <?php do_settings_sections('wc-monthly-settings') ?>
            <?php submit_button(); ?>
        </form>
    </div>
    <div id="footertext" class="wrap wrapCustom">
        <p>
            If there are problems with the plugin, please contact us by sending an email to <a href="support@4bis.nl">support@4bis.nl</a> or fill in the contact form at <a href="https://4bis.nl/contact">4bis.nl</a>
        </p>
    </div>
    <?php
}

