<?php

/**
 * Daily cron that checks if its the first day of the month
 **/
function fwer_email_cron_monthly()
{
    if (date('j') === '1') {
        fourbis_monthly_mail();
    }
}
add_action('fwer_email_cron_monthly', 'fwer_email_cron_monthly', 1);

/**
 * Function that grabs all completed orders and returns the totals
 **/
function fourbis_sales_summary($start_date, $end_date)
{
    $customer_orders = get_posts(array(
        'numberposts' => -1,
        'post_type' => array('shop_order'),
        'post_status' => array('wc-completed'),
        'date_query' => array(
            'after' => $start_date,
            'before' => $end_date,
            'inclusive' => true
        )
    ));

    $total = 0;
    $totalOrder = 0;
    $totalProducts = 0;

    foreach ($customer_orders as $customer_order) {
        $order = wc_get_order($customer_order);

        $total += $order->get_total();
        $totalOrder += $order;
        $totalProducts += $order->get_item_count();
    }

    $dataOrders = [$total, $totalOrder, $totalProducts];

    return $dataOrders;
}

/**
 * Function that grabs the monthly product sales
 **/
function fourbis_monthly_product_sales($start_date, $end_date)
{
    global $woocommerce, $product;
    $tablecelltextcolor = esc_attr(get_option('fwer_main_mail_settings')['table_cell_text_color']);
    $tablecolor = esc_attr(get_option('fwer_main_mail_settings')['table_color']);

    include_once($woocommerce->plugin_path() . '/includes/admin/reports/class-wc-admin-report.php');

    $wc_report = new WC_Admin_Report();

    $wc_report->start_date = strtotime($start_date);
    $wc_report->end_date = strtotime($end_date);

    $sold_products = $wc_report->get_order_report_data(array(
        'data' => array(
            '_product_id' => array(
                'type' => 'order_item_meta',
                'order_item_type' => 'line_item',
                'function' => '',
                'name' => 'id_product'
            ),
            '_qty' => array(
                'type' => 'order_item_meta',
                'order_item_type' => 'line_item',
                'function' => 'SUM',
                'name' => 'quantity'
            ),
            '_line_subtotal' => array(
                'type' => 'order_item_meta',
                'order_item_type' => 'line_item',
                'function' => 'SUM',
                'name' => 'gross'
            ),
            '_line_subtotal_tax' => array(
                'type' => 'order_item_meta',
                'order_item_type' => 'line_item',
                'function' => 'SUM',
                'name' => 'gross_tax'
            ),
            '_line_total' => array(
                'type' => 'order_item_meta',
                'order_item_type' => 'line_item',
                'function' => 'SUM',
                'name' => 'gross_after_discount'
            )
        ),
        'query_type' => 'get_results',
        'group_by' => 'id_product',
        'where_meta' => '',
        'order_by' => 'quantity DESC',
        'order_types' => wc_get_order_types('order_count'),
        'filter_range' => TRUE,
        'order_status' => array('completed'),
    ));

    ob_start();

    foreach ($sold_products as $product) {
        ?>
        <tr>
            <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                <?php
                $product_name = html_entity_decode(get_the_title($product->id_product));
                if ($product_name != null) {
                    echo $product_name;
                } else {
                    echo "<p style='color: red; font-weight: bold'>(Product is nameless)</p>";
                }
                ?>
            </td>
            <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;text-align:right;"><?php echo intval($product->quantity); ?></td>

            <?php
            $price = $product->gross;
            $price_tax = $product->gross_tax;
            $product_price = wc_price($price);
            $product_tax = wc_price($price_tax);
            ?>

            <td style="color:<?php echo $tablecelltextcolor ?>; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;text-align:right;"><?php echo $product_price; ?></td>
            <td style="color:<?php echo $tablecelltextcolor ?>; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;text-align:right;"><?php echo $product_tax; ?></td>

        </tr>
        <?php
    }
    return ob_get_clean();
}

/**
 * Function that grabs a list of all products sold
 **/
function fourbis_products_sold_list($start_date, $end_date)
{
    $prijspstukExclbtw = esc_attr(get_option('fwer_main_mail_settings')['prijspstukexclbtw']);
    $hoeveelheid = esc_attr(get_option('fwer_main_mail_settings')['hoeveelheid']);
    $totaalexclbtw = esc_attr(get_option('fwer_main_mail_settings')['prijs_totaal_excl_btw']);
    $btw_price_apiece = esc_attr(get_option('fwer_main_mail_settings')['btw_price_apiece']);
    $btw = esc_attr(get_option('fwer_main_mail_settings')['btw']);
    $billingphone = esc_attr(get_option('fwer_main_mail_settings')['billing_phone']);
    $billingcountry = esc_attr(get_option('fwer_main_mail_settings')['billing_country']);
    $billingemail = esc_attr(get_option('fwer_main_mail_settings')['billing_email']);
    $tablecelltextcolor = esc_attr(get_option('fwer_main_mail_settings')['table_cell_text_color']);
    $tablecolor = esc_attr(get_option('fwer_main_mail_settings')['table_color']);

    $lm_orders = get_posts(array(
        'numberposts' => -1,
        'post_type' => array('shop_order'),
        'post_status' => array('wc-completed'),
        'date_query' => array(
            'after' => $start_date,
            'before' => $end_date
        )
    ));
    ob_start();

    foreach ($lm_orders as $lm_order) {

        $order = wc_get_order($lm_order);
        $mail = $order->get_billing_email();
        $fname = $order->get_billing_first_name();
        $lname = $order->get_billing_last_name();
        $country = $order->get_billing_country();
        $phone = $order->get_billing_phone();
        $order_id = $order->get_id();

        $order_date = $order->get_date_created();
        $order_date = date_format($order_date, 'd-m-Y');

        $order_products = $order->get_items();

        /**
         * @var WC_Order_Item_Product $order_product
         */
        foreach ($order_products as $order_product) {
            $order_product_name = $order_product->get_name();
            $order_product_qty = $order_product->get_quantity();
            $order_product_id = $order_product->get_product_id();             //No use
            $order_product_total = $order_product->get_total();
            $order_product_total_tax = $order_product->get_total_tax();

            $order_product_total_inc_btw = $order_product_total + $order_product_total_tax;

            $order_vat_price = $order_product_total_tax / $order_product->get_quantity();

            $order_product_price_excl_tax = $order_product_total / $order_product->get_quantity();
            ?>

            <tr>
                <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo $order_id ?></td>
                <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo $order_date ?></td>
                <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo $fname . ' ' . $lname ?></td>
                <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo $order_product_name ?></td>
                <?php
                if ($prijspstukExclbtw == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . wc_price($order_product_price_excl_tax) . '</td>';
                }

                if ($btw_price_apiece == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . wc_price($order_vat_price) . '</td>';
                }

                if ($hoeveelheid == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . $order_product_qty . '</td>';
                }

                if ($btw == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;;">' . wc_price($order_product_total_tax) . '</td>';
                }

                if ($totaalexclbtw == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . wc_price($order_product_total) . '</td>';
                }
                ?>

                <td style="color:<?php echo $tablecelltextcolor ?>; width:auto; border: 1px solid <?php echo $tablecolor ?>; padding:5px; text-align:right;"><?php echo wc_price($order_product_total_inc_btw) ?></td>

                <?php
                if ($billingemail == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . $mail . '</td>';
                }
                if ($billingcountry == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . $country . '</td>';
                }
                if ($billingphone == 1) {
                    echo '<td style="color:' . $tablecelltextcolor . '; width:auto; border: 1px solid ' . $tablecolor . '; padding:5px; text-align:right;">' . $phone . '</td>';
                }
                ?>
            </tr>
            <?php
        }
    }
    return ob_get_clean();
}

/**
 * Makes the html of the email
 **/
function fourbis_get_monthly_email_report($start_date, $end_date, $mail_comment)
{
    $prijspstukExclbtw = esc_attr(get_option('fwer_main_mail_settings')['prijspstukexclbtw']);
    $hoeveelheid = esc_attr(get_option('fwer_main_mail_settings')['hoeveelheid']);
    $totaalexclbtw = esc_attr(get_option('fwer_main_mail_settings')['prijs_totaal_excl_btw']);
    $btw_price_apiece = esc_attr(get_option('fwer_main_mail_settings')['btw_price_apiece']);
    $btw = esc_attr(get_option('fwer_main_mail_settings')['btw']);
    $billingphone = esc_attr(get_option('fwer_main_mail_settings')['billing_phone']);
    $billingcountry = esc_attr(get_option('fwer_main_mail_settings')['billing_country']);
    $billingemail = esc_attr(get_option('fwer_main_mail_settings')['billing_email']);
    $tablecelltextcolor = esc_attr(get_option('fwer_main_mail_settings')['table_cell_text_color']);
    $tablecolor = esc_attr(get_option('fwer_main_mail_settings')['table_color']);
    $tableheadtextcolor = esc_attr(get_option('fwer_main_mail_settings')['table_head_text_color']);

    $logo = ($user_logo = et_get_option('divi_logo'));
    ob_start();

    if ($mail_comment != null) {
        echo
            "
            <head>
                <style>
                   /* Remove space around the email design. */
                   html, body {
                       margin: 0 auto !important;
                       padding: 0 !important;
                       height: 100% !important;
                       width: 100% !important;
                   }
                
                   /* Stop Outlook resizing small text. */
                   * {
                       -ms-text-size-adjust: 100%;
                   }
                
                   /* Stop Outlook from adding extra spacing to tables. */
                   table, td {
                       mso-table-lspace: 0pt !important;
                       mso-table-rspace: 0pt !important;
                   }
                
                   /* Use a better rendering method when resizing images in Outlook IE. */
                   img {
                     -ms-interpolation-mode:bicubic;
                   }
                
                    /* Prevent Windows 10 Mail from underlining links. Styles for underlined links should be inline. */
                   a {
                       text-decoration: none;
                   }
                </style>
            </head>
            <body>
           
        <div style='margin: 0 0 20px 0;'> 
        <h3 style='margin: 0 0 5px 0'>Comments: </h3>
            <p style='margin: 0; font-size: 15px;'>" . $mail_comment . "</p>
        </div>
        ";
    }
    ?>
    <div style="width: 90%; display:flex; flex-direction: row; justify-content: space-between; margin-bottom: 50px;">
        <div class="logo_container">
            <img src="<?php echo esc_attr($logo); ?>" style="height: 80px; float:right;"
                 alt="<?php echo esc_attr(get_bloginfo('name')); ?>" id="logo">
        </div>
        <h1>Woocommerce Monthly Report</h1>
    </div>

    <table style="width:100%;  border-collapse: collapse;">
        <tr>
            <td colspan="100%" style="background-color:<?php echo $tablecolor ?>;height:30px;  font-weight:bold; font-size:16px; color:<?php echo $tableheadtextcolor ?>; padding:5px;">
                Sales summary of the period <?php echo $start_date ?> till <?php echo $end_date ?>
            </td>
        </tr>
        <tr>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Total completed orders
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Total amount sold
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Total number of products sold
            </th>
        </tr>
        <tr>
            <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo fourbis_sales_summary($start_date, $end_date)[1] ?> </td>
            <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo wc_price(fourbis_sales_summary($start_date, $end_date)[0]) ?> </td>
            <td style="color:<?php echo $tablecelltextcolor ?>; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;"><?php echo fourbis_sales_summary($start_date, $end_date)[2] ?></td>
        </tr>
    </table>

    <table>
        <tr>
            <td colspan="2" style="height:50px;"></td>
        </tr>
        <tr>
            <td colspan="2" style="width:100%"></td>
        </tr>
    </table>

    <table style="width:100%;  border-collapse: collapse;">
        <tr>
            <td colspan="4" style="color:<?php echo $tablecelltextcolor ?>;background-color:<?php echo $tablecolor ?>;height:30px;  font-weight:bold; font-size:16px; color:<?php echo $tableheadtextcolor ?>;padding:5px;">
                Total Products sold in the period <?php echo $start_date ?> till <?php echo $end_date ?>
            </td>
        </tr>
        <tr>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Product name
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Quantity
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Price excl. VAT
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:25%;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                VAT
            </th>
        </tr>
        <?php echo fourbis_monthly_product_sales($start_date, $end_date); ?>
    </table>

    <table>
        <tr>
            <td colspan="2" style="height:50px;"></td>
        </tr>
        <tr>
            <td colspan="2" style="width:100%"></td>
        </tr>
    </table>

    <table style="width:100%;  border-collapse: collapse;">
        <tr>
            <td colspan="100%" style="background-color:<?php echo $tablecolor ?>;height:30px;  font-weight:bold; font-size:16px; color:<?php echo $tableheadtextcolor ?>; padding:5px;">
                List of products sold in the period <?php echo $start_date ?> till <?php echo $end_date ?>
            </td>
        </tr>
        <tr>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Order ID
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Date
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Name
            </th>
            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Product Name
            </th>

            <?php
            if ($prijspstukExclbtw == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    Price p. piece excl. VAT
                </th> 
                ';
            }

            if ($btw_price_apiece == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    VAT per piece
                </th> 
                ';
            }

            if ($hoeveelheid == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    Quantity
                </th> 
                ';
            }

            if ($btw == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    VAT Total
                </th> 
                ';
            }

            if ($totaalexclbtw == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    Total price excl. VAT
                </th>
                ';
            }
            ?>

            <th style="color:<?php echo $tablecelltextcolor ?>;font-weight:bold; text-align:left; width:auto;border: 1px solid <?php echo $tablecolor ?>; padding:5px;">
                Price Total
            </th>

            <?php
            if ($billingemail == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    Email
                </th>
                ';
            }

            if ($billingcountry == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    Country
                </th>
                ';
            }

            if ($billingphone == 1) {
                echo '
                <th style="color:' . $tablecelltextcolor . ';font-weight:bold; text-align:left; width:auto;border: 1px solid ' . $tablecolor . '; padding:5px;">
                    Phone number
                </th>
                ';
            }
            ?>
        </tr>
        <?php echo fourbis_products_sold_list($start_date, $end_date); ?>
    </table>
    </body>
    <?php

    $result = ob_get_contents();
    ob_end_clean();

    return $result;
}

/**
 * Grabs the settings and the html mail and sends the email
 **/
function fourbis_monthly_mail()
{
    $mailto = esc_attr(get_option('fwer_main_mail_settings')['to']);
    $mailfrom = esc_attr(get_option('fwer_main_mail_settings')['from']);
    $subject = esc_attr(get_option('fwer_main_mail_settings')['subject']);
    $cc = esc_attr(get_option('fwer_main_mail_settings')['cc']);

    $start_date = date_i18n("d-m-Y", strtotime("-1 month")); //Start date
    $end_date = date_i18n("d-m-Y");

    $mail_comment = esc_attr(get_option('fwer_main_mail_settings')['mail_comment']);

    $output = fourbis_get_monthly_email_report($start_date, $end_date, $mail_comment);

    $message = $output;

    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";
    $headers .= 'From: ' . $mailfrom . "\r\n";
    $headers .= 'CC: ' . $cc . "\r\n";

    wp_mail($mailto, $subject, $message, $headers);
}

